@@ -2,7 +2,7 @@
 #
 # Author: Mike McKerns (mmckerns @caltech and @uqfoundation)
 # Copyright (c) 1997-2016 California Institute of Technology.
-# Copyright (c) 2016-2019 The Uncertainty Quantification Foundation.
+# Copyright (c) 2016-2022 The Uncertainty Quantification Foundation.
 # License: 3-clause BSD.  The full license text is available at:
 #  - https://github.com/uqfoundation/pathos/blob/master/LICENSE
 """
@@ -13,7 +13,7 @@ Usage: python sum_primesX.py [tunnelport]
     if omitted no tunneling will be used.
 
 To establish a ssh-tunneled server, please see
-    $ tunneled_pathos_server.py --help
+    $ pathos_connect --help
 """
 
 import math
